log

package
v0.13.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

func NewModel added in v0.13.5

func NewModel(worktreeRoot, startRef string, settings Settings) Model

func (Model) ChordHints added in v0.13.2

func (m Model) ChordHints(prefix string) []key.Binding

ChordHints returns the available chord completions for the given prefix. Implements ui.ChordHinter.

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) InputFocused added in v0.13.0

func (m Model) InputFocused() bool

func (Model) SelectRef added in v0.13.0

func (m Model) SelectRef(fullHash string) Model

SelectRef returns a copy with cursor moved to the commit matching fullHash. If no matching row is found, cursor is unchanged.

func (Model) SelectedRef added in v0.13.0

func (m Model) SelectedRef() string

SelectedRef returns the full hash of the currently selected commit row.

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() tea.View

type Settings

type Settings struct {
	UseNerdFontIcons bool
	InputModalBottom config.InputModalBottom
	EnableNavigation bool
}

Jump to