worktrees

package
v0.15.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: MIT Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the BubbleTea model for the worktrees page.

func New

func New(repo git.Repo, activeWorktreePath string) Model

New creates a new worktrees page model. activeWorktreePath is the path of the worktree the user is currently in (empty if launched from the bare repo root).

func NewWithSettings

func NewWithSettings(repo git.Repo, activeWorktreePath string, settings ui.Settings) Model

NewWithSettings creates a new worktrees page model with explicit settings.

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) InputFocused added in v0.13.0

func (m Model) InputFocused() bool

func (Model) KeyManager added in v0.14.5

func (m Model) KeyManager() keymgr.Manager

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() tea.View

Jump to