Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
func (Model) ChordHints ¶ added in v0.13.2
ChordHints returns the available chord completions for the given prefix. Implements ui.ChordHinter.
func (Model) InputFocused ¶ added in v0.13.0
func (Model) SelectRef ¶ added in v0.13.0
SelectRef returns a copy with cursor moved to the commit matching fullHash. If no matching row is found, cursor is unchanged.
func (Model) SelectedRef ¶ added in v0.13.0
SelectedRef returns the full hash of the currently selected commit row.
type Settings ¶
type Settings struct {
UseNerdFontIcons bool
InputModalBottom config.InputModalBottom
}
Click to show internal directories.
Click to hide internal directories.