Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model is the BubbleTea model for the worktrees page.
func New ¶
New creates a new worktrees page model. activeWorktreePath is the path of the worktree the user is currently in (empty if launched from the bare repo root).
func NewWithSettings ¶
NewWithSettings creates a new worktrees page model with explicit settings.
func (Model) InputFocused ¶ added in v0.13.0
func (Model) KeyManager ¶ added in v0.14.5
Source Files
¶
- clone.go
- delete.go
- icons.go
- keys.go
- kitty.go
- lazygit.go
- model_commands.go
- model_confirm_modal.go
- model_credential_prompt.go
- model_error_modal.go
- model_help.go
- model_keys.go
- model_layout.go
- model_logs_modal.go
- model_messages.go
- model_pull.go
- model_push_diverged.go
- model_state.go
- model_update.go
- model_view.go
- new.go
- paste.go
- pullpush.go
- remoteupdate.go
- rename.go
- search.go
- sidebar.go
- table.go
- terminal_menu.go
- tmux.go
- track.go
- yank.go
Click to show internal directories.
Click to hide internal directories.